@@ -1,37 +1,51 @@
-#' @title Plot interaction terms (moderation) of linear models
-#' @name sjp.lm.int
-#' 
+#' @title Plot interaction effects of (generalized) linear (mixed) models
+#' @name sjp.int
+#'
 #' @references \itemize{
 #'              \item \href{http://www.theanalysisfactor.com/interpreting-interactions-in-regression/}{Grace-Martin K: Interpreting Interactions in Regression}
 #'              \item \href{http://www.theanalysisfactor.com/clarifications-on-interpreting-interactions-in-regression/}{Grace-Martin K: Clarifications on Interpreting Interactions in Regression}
 #'              \item \href{http://www.theanalysisfactor.com/3-tips-interpreting-moderation/}{Grace-Martin K: 3 Tips to Make Interpreting Moderation Effects Easier}
 #'              \item Aiken and West (1991). Multiple Regression: Testing and Interpreting Interactions.
 #'              }
-#'             
-#' @description Plot regression curves of significant interaction terms (moderation) in linear models (lm). Note that beside interaction
-#'                terms, also the single predictors of each interaction must be included in the fitted model as well.
-#'                Thus, \code{lm(dep~pred1*pred2)} will work, but \code{lm(dep~pred1:pred2)} won't!
-#' 
-#' @note Beside interaction terms, also the single predictors of each interaction must be included in the fitted model as well.
-#'         Thus, \code{lm(dep~pred1*pred2)} will work, but \code{lm(dep~pred1:pred2)} won't!
-#' 
+#'
+#' @description Plot regression or probability lines of significant interaction terms to better understand effects
+#'                of moderations in regression models. This function accepts following fitted model classes:
+#'                \itemize{
+#'                  \item linear models (\code{lm})
+#'                  \item generalized linear models (\code{glm})
+#'                  \item linear mixed effects models (\code{lme4::lmer})
+#'                  \item generalized linear mixed effects models (\code{lme4::glmer})
+#'                }
+#'                Note that beside interaction terms, also the single predictors of each interaction (main effects)
+#'                must be included in the fitted model as well. Thus, \code{lm(dep ~ pred1 * pred2)} will work, 
+#'                but \code{lm(dep ~ pred1:pred2)} won't!
+#'
+#' @note Note that beside interaction terms, also the single predictors of each interaction (main effects)
+#'        must be included in the fitted model as well. Thus, \code{lm(dep ~ pred1 * pred2)} will work, 
+#'        but \code{lm(dep ~ pred1:pred2)} won't!
+#'
 #' @seealso \itemize{
-#'            \item \code{\link{sjp.lm}}
 #'            \item \code{\link{sjp.emm.int}}
 #'            \item \code{\link{sjp.reglin}}
-#'            \item \code{\link{sjp.lm.ma}}
 #'            }
-#' 
-#' @param fit the fitted linear model (lm) object, including interaction terms
+#'
+#' @param fit the fitted (generalized) linear (mixed) model object, including interaction terms. Accepted model
+#'          classes are
+#'          \itemize{
+#'            \item linear models (\code{lm})
+#'            \item generalized linear models (\code{glm})
+#'            \item linear mixed effects models (\code{lme4::lmer})
+#'            \item generalized linear mixed effects models (\code{lme4::glmer})
+#'            }
 #' @param diff if \code{FALSE} (default), the minimum and maximum interaction effects of predictor 2 on predictor 1
 #'          are shown (one line each). if \code{TRUE}, only the difference between minimum and maximum interaction effect
 #'          is shown (single line)
-#' @param moderatorValues indicates which values of the moderator variable should be used when plotting the effects of the 
+#' @param moderatorValues indicates which values of the moderator variable should be used when plotting the effects of the
 #'          independent variable on the dependent variable. By default, \code{"minmax"} is used, i.e. the minimum and maximum values
 #'          (lower and upper bounds) of the moderator are used to plot the interaction between independent variable and moderator.
 #'          Use \code{"meansd"} to use the mean value of the moderator as well as one standard deviation below and above mean value
 #'          to plot the effect of the moderator on the independent variable (following
-#'          the convention suggested by Cohen and Cohen and popularized by Aiken and West, 
+#'          the convention suggested by Cohen and Cohen and popularized by Aiken and West,
 #'          i.e. using the mean, the value one standard deviation above, and the value one standard deviation below the mean
 #'          as values of the moderator, see \href{http://www.theanalysisfactor.com/3-tips-interpreting-moderation/}{Grace-Martin K: 3 Tips to Make Interpreting Moderation Effects Easier}).
 #' @param swapPredictors if \code{TRUE}, the predictor with less unique values is printed along the x-axis. Default is
@@ -44,24 +58,24 @@
 #'          Either set \code{fillColor} to \code{NULL} or use 0 for \code{fillAlpha} if you want to hide the shaded area.
 #' @param fillAlpha alpha value (transparancy) of the shaded area between the minimum and maximum lines. Default is 0.4.
 #'          Use either 0 or set \code{fillColor} to \code{NULL} if you want to hide the shaded area.
-#' @param geom.colors A vector of color values. First value is the color of the line indicating the lower bound of 
-#'          the interaction term (moderator value). Second value is the color of the line indicating the upper bound of 
-#'          the interaction term (moderator value). Third value, if applicable, is the color of the line indicating the 
-#'          mean value of the interaction term (moderator value). Third value is only used when \code{moderatorValues} 
-#'          is \code{"meansd"}. Or, if \code{diff} is \code{TRUE}, only one color value for the line indicating the 
+#' @param geom.colors A vector of color values. First value is the color of the line indicating the lower bound of
+#'          the interaction term (moderator value). Second value is the color of the line indicating the upper bound of
+#'          the interaction term (moderator value). Third value, if applicable, is the color of the line indicating the
+#'          mean value of the interaction term (moderator value). Third value is only used when \code{moderatorValues}
+#'          is \code{"meansd"}. Or, if \code{diff} is \code{TRUE}, only one color value for the line indicating the
 #'          upper difference between lower and upper bound of interaction terms.
-#' @param axisTitle.x a default title used for the x-axis. Default value is \code{NULL}, 
+#' @param axisTitle.x a default title used for the x-axis. Default value is \code{NULL},
 #'          which means that each plot's x-axis uses the predictor's name as title.
-#' @param axisTitle.y a default title used for the y-axis. Default value is \code{NULL}, 
+#' @param axisTitle.y a default title used for the y-axis. Default value is \code{NULL},
 #'          which means that each plot's y-axis uses the dependent variable's name as title.
-#' @param legendLabels Labels for the guide/legend. Default is \code{NULL}, so the name of the predictor with 
+#' @param legendLabels Labels for the guide/legend. Default is \code{NULL}, so the name of the predictor with
 #'          min/max-effect is used as legend label.
 #' @param showValueLabels if \code{TRUE}, value labels are plotted along the lines. Default is \code{FALSE}.
-#' @param breakTitleAt Wordwrap for diagram's title. Determines how many chars of the title are 
+#' @param breakTitleAt Wordwrap for diagram's title. Determines how many chars of the title are
 #'          displayed in one line and when a line break is inserted. Default is \code{50}.
-#' @param breakLegendLabelsAt Wordwrap for diagram legend labels. Determines how many chars of the legend labels are 
+#' @param breakLegendLabelsAt Wordwrap for diagram legend labels. Determines how many chars of the legend labels are
 #'          displayed in one line and when a line break is inserted. Default is \code{20}.
-#' @param breakAnnotationLabelsAt Wordwrap for diagram annotation labels. Determines how many chars of the legend labels are 
+#' @param breakAnnotationLabelsAt Wordwrap for diagram annotation labels. Determines how many chars of the legend labels are
 #'          displayed in one line and when a line break is inserted. Default is \code{50}.
 #'          Only applies if \code{showInterceptLine} is \code{TRUE}.
 #' @param axisLimits.y A vector with two values, defining the lower and upper limit from the y-axis.
@@ -85,74 +99,130 @@
 #'          variable name. By default, this string is \code{"(no interaction)"}.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
 #'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
-#' @return (Insisibily) returns the ggplot-objects with the complete plot-list (\code{plot.list}) 
+#' @return (Insisibily) returns the ggplot-objects with the complete plot-list (\code{plot.list})
 #'           as well as the data frame that were used for setting up the ggplot-objects (\code{df.list}).
-#' 
+#'
 #' @examples
 #' # Note that the data sets used in this example may not be perfectly suitable for
 #' # fitting linear models. I just used them because they are part of the R-software.
-#' 
+#'
 #' # fit "dummy" model.
-#' fit <- lm(weight ~ Time * Diet, data=ChickWeight, x=TRUE)
-#' 
+#' fit <- lm(weight ~ Time * Diet,
+#'           data = ChickWeight,
+#'           x = TRUE)
+#'
 #' # show summary to see significant interactions
 #' summary(fit)
-#' 
+#'
 #' # plot regression line of interaction terms
-#' sjp.lm.int(fit)
+#' sjp.int(fit)
 #' # plot regression line of interaction terms, including value labels
-#' sjp.lm.int(fit, showValueLabels=TRUE)
-#' 
-#' 
+#' sjp.int(fit, showValueLabels = TRUE)
+#'
+#'
 #' # load sample data set
 #' data(efc)
 #' # create data frame with variables that should be included
 #' # in the model
-#' df <- as.data.frame(cbind(usage=efc$tot_sc_e,
-#'                           sex=efc$c161sex, 
-#'                           education=efc$c172code, 
-#'                           burden=efc$neg_c_7, 
-#'                           dependency=efc$e42dep))
-#' # convert gender predictor to factor                         
-#' df$sex <- relevel(factor(df$sex), ref="2")
+#' mydf <- data.frame(usage = efc$tot_sc_e,
+#'                    sex = efc$c161sex,
+#'                    education = efc$c172code,
+#'                    burden = efc$neg_c_7,
+#'                    dependency = efc$e42dep)
+#' # convert gender predictor to factor
+#' mydf$sex <- relevel(factor(mydf$sex), ref = "2")
 #' # fit "dummy" model
-#' fit <- lm(usage ~ .*., data=df, x=TRUE)
+#' fit <- lm(usage ~ .*., data = mydf, x = TRUE)
 #' summary(fit)
-#' 
+#'
 #' # plot interactions
-#' sjp.lm.int(fit)
+#' sjp.int(fit)
+#'
+#' # plot interactions, using mean and sd as moderator
+#' # values to calculate interaction effect
+#' sjp.int(fit, moderatorValues = "meansd")
+#'
 #' # plot interactions, including those with p-value up to 0.1
-#' sjp.lm.int(fit, plevel=0.1, showInterceptLines=TRUE)
-#' 
-#' 
+#' sjp.int(fit,
+#'         plevel = 0.1,
+#'         showInterceptLines = TRUE)
+#'
+#' # -------------------------------
+#' # Predictors for negative impact of care.
+#' # Data from the EUROFAMCARE sample dataset
+#' # -------------------------------
+#' data(efc)
+#' # create binary response
+#' y <- ifelse(efc$neg_c_7 < median(na.omit(efc$neg_c_7)), 0, 1)
+#' # create data frame for fitted model
+#' mydf <- data.frame(y = as.factor(y),
+#'                    sex = as.factor(efc$c161sex),
+#'                    barthel = as.numeric(efc$barthtot))
+#' # fit model
+#' fit <- glm(y ~ sex * barthel,
+#'            data = mydf,
+#'            family = binomial(link = "logit"),
+#'            x = TRUE)
+#' # plot interaction, increase p-level sensivity
+#' sjp.int(fit,
+#'         legendLabels = sji.getValueLabels(efc$c161sex),
+#'         plevel = 0.1)
+#'
+#' # compare results to boxplots
+#' sjp.grpfrq(mydf$barthel,
+#'            mydf$y,
+#'            interactionVar = mydf$sex,
+#'            interactionVarLabels = sji.getValueLabels(efc$c161sex),
+#'            legendLabels = c("low burden", "high burden"),
+#'            type = "box")
+#'
 #' @import ggplot2
 #' @export
-sjp.lm.int <- function(fit,
-                      diff=FALSE,
-                      moderatorValues="minmax",
-                      swapPredictors=FALSE,
-                      plevel=0.05,
-                      title=NULL,
-                      fillColor="grey",
-                      fillAlpha=0.4,
-                      geom.colors="Set1",
-                      axisTitle.x=NULL,
-                      axisTitle.y=NULL,
-                      legendLabels=NULL,
-                      showValueLabels=FALSE,
-                      breakTitleAt=50,
-                      breakLegendLabelsAt=20,
-                      breakAnnotationLabelsAt=50,
-                      axisLimits.y=NULL,
-                      gridBreaksAt=NULL,
-                      showInterceptLines=FALSE,
-                      showInterceptLabels=TRUE,
-                      interceptLineColor="darkseagreen4",
-                      estLineColor="darkslategray4",
-                      lineLabelSize=3.7,
-                      lineLabelColor="black",
-                      lineLabelString="(no interaction)",
-                      printPlot=TRUE) {
+sjp.int <- function(fit,
+                    diff=FALSE,
+                    moderatorValues="minmax",
+                    swapPredictors=FALSE,
+                    plevel=0.05,
+                    title=NULL,
+                    fillColor="grey",
+                    fillAlpha=0.4,
+                    geom.colors="Set1",
+                    axisTitle.x=NULL,
+                    axisTitle.y=NULL,
+                    legendLabels=NULL,
+                    showValueLabels=FALSE,
+                    breakTitleAt=50,
+                    breakLegendLabelsAt=20,
+                    breakAnnotationLabelsAt=50,
+                    axisLimits.y=NULL,
+                    gridBreaksAt=NULL,
+                    showInterceptLines=FALSE,
+                    showInterceptLabels=TRUE,
+                    interceptLineColor="darkseagreen4",
+                    estLineColor="darkslategray4",
+                    lineLabelSize=3.7,
+                    lineLabelColor="black",
+                    lineLabelString="(no interaction)",
+                    printPlot=TRUE) {
+  # -----------------------------------------------------------
+  # check class of fitted model
+  # -----------------------------------------------------------
+  c.f <- class(fit)
+  if (length(c.f) == 1 && c.f == "lm") {
+    fun <- "lm"
+  }
+  else if (length(c.f) > 1 && any(c.f == "glm")) {
+    fun <- "glm"
+  }
+  else if (c.f == "lmerMod") {
+    fun <- "lmer"
+  }
+  else if (c.f == "glmerMod") {
+    fun <- "glmer"
+  }
+  if ((fun == "glm" || fun == "glmer") && is.null(axisTitle.y)) {
+    axisTitle.y <- "Probability"
+  }
   # -----------------------------------------------------------
   # parameter check
   # -----------------------------------------------------------
@@ -170,26 +240,94 @@ sjp.lm.int <- function(fit,
     legendLabels <- unlistlabels(legendLabels)
   }
   # -----------------------------------------------------------
-  # retrieve amount and names of predictor variables and
-  # of dependent variable
+  # prepare values for (generalized) linear models
   # -----------------------------------------------------------
-  predvars <- attr(attr(fit$terms, "dataClasses"), "names")[-1]
-  depvar.label <- attr(attr(fit$terms, "dataClasses"), "names")[1]
-  # remember length of predictor variables
-  predvars.length <- length(predvars)
+  if (fun == "lm" || fun == "glm") {
+    # -----------------------------------------------------------
+    # retrieve amount and names of predictor variables and
+    # of dependent variable
+    # -----------------------------------------------------------
+    predvars <- attr(attr(fit$terms, "dataClasses"), "names")[-1]
+    depvar.label <- attr(attr(fit$terms, "dataClasses"), "names")[1]
+    # remember length of predictor variables
+    predvars.length <- length(predvars)
+    # -----------------------------------------------------------
+    # retrieve p-values, without intercept
+    # -----------------------------------------------------------
+    pval <- summary(fit)$coefficients[-1, 4]
+    # -----------------------------------------------------------
+    # retrieve estimates, without intercept
+    # -----------------------------------------------------------
+    estimates <- summary(fit)$coefficients[-1, 1]
+    estimates.names <- it <- names(estimates)
+    # -----------------------------------------------------------
+    # retrieve estimate of intercept
+    # -----------------------------------------------------------
+    b0 <- estimates.intercept <- summary(fit)$coefficients[1, 1]
+  }
   # -----------------------------------------------------------
-  # retrieve p-values, without intercept
+  # prepare values for (generalized) linear mixed effecrs models
   # -----------------------------------------------------------
-  pval <- summary(fit)$coefficients[-1, 4]
-  # -----------------------------------------------------------
-  # retrieve estimates, without intercept
-  # -----------------------------------------------------------
-  estimates <- summary(fit)$coefficients[-1, 1]
-  estimates.names <- names(estimates)
-  # -----------------------------------------------------------
-  # retrieve estimate of intercept
-  # -----------------------------------------------------------
-  b0 <- estimates.intercept <- summary(fit)$coefficients[1, 1]
+  else {
+    # -----------------------------------------------------------
+    # retrieve amount and names of predictor variables and
+    # of dependent variable
+    # -----------------------------------------------------------
+    predvars <- colnames(fit@frame)[-1]
+    depvar.label <- colnames(fit@frame)[1]
+    # remember length of predictor variables
+    predvars.length <- length(predvars)
+    # -----------------------------------------------------------
+    # retrieve p-values, without intercept
+    # -----------------------------------------------------------
+    pval <- summary(fit)$coefficients[-1, 4]
+    # -----------------------------------------------------------
+    # retrieve estimates, without intercept
+    # -----------------------------------------------------------
+    estimates <- unname(lme4::fixef(fit)[-1])
+    estimates.names <- names(lme4::fixef(fit)[-1])
+    # -----------------------------------------------------------
+    # copy variable values to data frame
+    # -----------------------------------------------------------
+    fitdat <- fit@frame
+    # -----------------------------------------------------------
+    # extract factors, to check whether factor levels are included
+    # as interaction terms. interaction terms with factors are labelled
+    # with additional factor levels (e.g. "sex" will be "sex2:age").
+    # However, since merMod objects don't return the model matrix,
+    # the data frame's variable names do not equal the term names.
+    # in order to find the original values of interaction terms in
+    # the data frame, we need to "rename" the terms into the related
+    # variable names in the data frame
+    # -----------------------------------------------------------
+    fac.names <- c()
+    # find factor variables
+    for (i in 1 : ncol(fitdat)) {
+      if (is.factor(fitdat[,i])) fac.names <- c(fac.names, colnames(fitdat)[i])
+    }
+    # if we found any, check if factor variable
+    # was used as interaction term
+    if (!is.null(fac.names)) {
+      for (i in 1 : length(fac.names)) {
+        # retrieve all factor levels except reference category
+        fac.lvl <- levels(fitdat[, fac.names[i]])[-1]
+        # iterate interaction term for all factor levels,
+        # and replace with "original variable name in data frame
+        for (j in 1 : length(fac.lvl)) {
+          # create replacement-strings
+          rep1 <- paste0(fac.names[i], fac.lvl[j])
+          rep2 <- paste0(fac.names[i])
+          # replace in all
+          estimates.names <- gsub(rep1, rep2, estimates.names, fixed = TRUE)
+        }
+      }
+    }
+    it <- estimates.names
+    # -----------------------------------------------------------
+    # retrieve estimate of intercept
+    # -----------------------------------------------------------
+    b0 <- estimates.intercept <- unname(lme4::fixef(fit)[1])
+  }
   # -----------------------------------------------------------
   # find all significant interactions
   # we start looking for significant p-values beginning
@@ -197,8 +335,6 @@ sjp.lm.int <- function(fit,
   # thus, the starting point is first position after all single
   # predictor variables
   # -----------------------------------------------------------
-  # retrieve position of interaction terms
-  it <- rownames(summary(fit)$coefficients)[-1]
   # init indicator for first term
   firstit <- 0
   # iterate all rownames. interaction terms contain a colon...
@@ -227,25 +363,20 @@ sjp.lm.int <- function(fit,
   if (is.null(intnames)) {
     stop("No significant interactions found...", call. = FALSE)
   }
-  # --------------------------------------------------------
-  # Check whether we have any estimate names. this variable is
-  # null in case we only have one interaction in the fitted
-  # model.
-  # --------------------------------------------------------
-  if (is.null(estimates.names)) {
-    estimates.names <- it
-  }
   # -----------------------------------------------------------
   # check whether parameter X=TRUE was set when fitting the linear
-  # model. if not, we cannot procede here
+  # model. if not, we cannot procede here. not needed for
+  # merMod objects, see above
   # -----------------------------------------------------------
-  if(class(fit$x) != "matrix") {
-    stop("The model matrix is not available! Please use \"x=TRUE\" in your lm-command...", call. = FALSE)
+  if(fun == "lm" || fun == "glm") {
+    if (class(fit$x) != "matrix") {
+      stop("The model matrix is not available! Please use \"x=TRUE\" in your (g)lm-command...", call. = FALSE)
+    }
+    # -----------------------------------------------------------
+    # copy variable values to data frame
+    # -----------------------------------------------------------
+    fitdat <- as.data.frame(fit$x)
   }
-  # -----------------------------------------------------------
-  # copy variable values to data frame
-  # -----------------------------------------------------------
-  fitdat <- as.data.frame(fit$x)
   # init vector that saves ggplot objects
   plotlist <- list()
   dflist <- list()
@@ -257,7 +388,7 @@ sjp.lm.int <- function(fit,
   # -----------------------------------------------------------
   for (cnt in 1:length(intnames)) {
     # -----------------------------------------------------------
-    # first, retrieve and split interaction term so we know 
+    # first, retrieve and split interaction term so we know
     # the two predictor variables of the interaction term
     # -----------------------------------------------------------
     interactionterms <- strsplit(intnames[cnt], ":")
@@ -272,11 +403,11 @@ sjp.lm.int <- function(fit,
     b2 <- as.numeric(estimates[match(interactionterms[[1]][2], estimates.names)])
     b3 <- as.numeric(estimates[match(intnames[cnt], estimates.names)])
     # -----------------------------------------------------------
-    # check whether each predictor was included in the model 
+    # check whether each predictor was included in the model
     # as single term as well
     # -----------------------------------------------------------
     if(is.na(b1) || is.na(b2) || is.na(b3)) {
-      stop("Predictors of interaction terms must be included as single term as well. See Note in ?sjp.lm.int", call. = FALSE)
+      stop("Predictors of interaction terms (main effects) must be included as single term as well. See Note in ?sjp.int", call. = FALSE)
     }
     # -----------------------------------------------------------
     # retrieve number of unique values in each predictor variable.
@@ -313,7 +444,7 @@ sjp.lm.int <- function(fit,
       predy <- c(interactionterms[[1]][2])
       # -----------------------------------------------------------
       # check which values of moderator should be plotted, i.e. if
-      # lower/upper bound (min-max) or mean and standard-deviation 
+      # lower/upper bound (min-max) or mean and standard-deviation
       # should be used as valus for the moderator.
       # see http://www.theanalysisfactor.com/3-tips-interpreting-moderation/
       # -----------------------------------------------------------
@@ -363,7 +494,7 @@ sjp.lm.int <- function(fit,
         # store in df
         if (moderatorValues != "minmax") {
           # ------------------------------
-          # here we calculate the effect of predictor 1 under presence 
+          # here we calculate the effect of predictor 1 under presence
           # of mean of predictor 2 on the dependent variable. Thus, the slope for
           # predictor 2 only is not needed. see references above
           # ------------------------------
@@ -378,7 +509,7 @@ sjp.lm.int <- function(fit,
       predy <- c(interactionterms[[1]][1])
       # -----------------------------------------------------------
       # check which values of moderator should be plotted, i.e. if
-      # lower/upper bound (min-max) or mean and standard-deviation 
+      # lower/upper bound (min-max) or mean and standard-deviation
       # should be used as valus for the moderator.
       # see http://www.theanalysisfactor.com/3-tips-interpreting-moderation/
       # -----------------------------------------------------------
@@ -429,7 +560,7 @@ sjp.lm.int <- function(fit,
         # store in df
         if (moderatorValues != "minmax") {
           # ------------------------------
-          # here we calculate the effect of predictor 2 under presence 
+          # here we calculate the effect of predictor 2 under presence
           # of mean of predictor 1 on the dependent variable. Thus, the slope for
           # predictor 1 only is not needed. see references above
           # ------------------------------
@@ -442,24 +573,47 @@ sjp.lm.int <- function(fit,
     # -----------------------------------------------------------
     # convert df-values to numeric
     # -----------------------------------------------------------
-    intdf$x <- as.numeric(as.character(intdf$x))
-    intdf$y <- as.numeric(as.character(intdf$y))
-    intdf$ymin <- as.numeric(as.character(intdf$ymin))
-    intdf$ymax <- as.numeric(as.character(intdf$ymax))
-    intdf$ydiff <- intdf$ymax-intdf$ymin
-    # -----------------------------------------------------------
-    # retrieve lowest and highest x and y position to determine
-    # the scale limits
-    # -----------------------------------------------------------
-    lowerLim.x <- floor(min(intdf$x))
-    upperLim.x <- ceiling(max(intdf$x))
-    if (is.null(axisLimits.y)) {
-      lowerLim.y <- floor(min(intdf$y))
-      upperLim.y <- ceiling(max(intdf$y))
+    if (fun == "lm" || fun == "lmer") {
+      intdf$x <- as.numeric(as.character(intdf$x))
+      intdf$y <- as.numeric(as.character(intdf$y))
+      intdf$ymin <- as.numeric(as.character(intdf$ymin))
+      intdf$ymax <- as.numeric(as.character(intdf$ymax))
+      intdf$ydiff <- intdf$ymax-intdf$ymin
+      # -----------------------------------------------------------
+      # retrieve lowest and highest x and y position to determine
+      # the scale limits
+      # -----------------------------------------------------------
+      lowerLim.x <- floor(min(intdf$x))
+      upperLim.x <- ceiling(max(intdf$x))
+      if (is.null(axisLimits.y)) {
+        lowerLim.y <- floor(min(intdf$y))
+        upperLim.y <- ceiling(max(intdf$y))
+      }
+      else {
+        lowerLim.y <- axisLimits.y[1]
+        upperLim.y <- axisLimits.y[2]
+      }
     }
     else {
-      lowerLim.y <- axisLimits.y[1]
-      upperLim.y <- axisLimits.y[2]
+      intdf$x <- as.numeric(as.character(intdf$x))
+      intdf$y <- odds.to.prob(as.numeric(as.character(intdf$y)))
+      intdf$ymin <- odds.to.prob(as.numeric(as.character(intdf$ymin)))
+      intdf$ymax <- odds.to.prob(as.numeric(as.character(intdf$ymax)))
+      intdf$ydiff <- odds.to.prob(intdf$ymax-intdf$ymin)
+      # -----------------------------------------------------------
+      # retrieve lowest and highest x and y position to determine
+      # the scale limits
+      # -----------------------------------------------------------
+      lowerLim.x <- floor(min(intdf$x))
+      upperLim.x <- ceiling(max(intdf$x))
+      if (is.null(axisLimits.y)) {
+        lowerLim.y <- 0
+        upperLim.y <- 1
+      }
+      else {
+        lowerLim.y <- axisLimits.y[1]
+        upperLim.y <- axisLimits.y[2]
+      }
     }
     # -----------------------------------------------------------
     # check whether we have to modify axis limits in case intercept
@@ -489,12 +643,12 @@ sjp.lm.int <- function(fit,
     # prepare plot title and axis titles
     # -----------------------------------------------------------
     if (is.null(title)) {
-#       labtitle <- paste0("Effect of ", interactionterms[[1]][ifelse(useFirstPredOnY==TRUE,1,2)], 
-#                          " on ", depvar.label, 
+#       labtitle <- paste0("Effect of ", interactionterms[[1]][ifelse(useFirstPredOnY==TRUE,1,2)],
+#                          " on ", depvar.label,
 #                          " under minimum and maximum interaction with ", interactionterms[[1]][ifelse(useFirstPredOnY==TRUE,2,1)])
-      labtitle <- paste0("Interaction of ", 
-                         interactionterms[[1]][ifelse(useFirstPredOnY == TRUE, 1, 2)], 
-                         " and ", 
+      labtitle <- paste0("Interaction of ",
+                         interactionterms[[1]][ifelse(useFirstPredOnY == TRUE, 1, 2)],
+                         " and ",
                          interactionterms[[1]][ifelse(useFirstPredOnY == TRUE, 2, 1)],
                          " on ", depvar.label)
     }
@@ -533,13 +687,13 @@ sjp.lm.int <- function(fit,
     # prepare base plot of interactions
     # -----------------------------------------------------------
     if (diff) {
-      baseplot <- ggplot(intdf, aes(x = x, y = ydiff)) + 
+      baseplot <- ggplot(intdf, aes(x = x, y = ydiff)) +
         # -----------------------------------------------------------
-        # add a shaded region between minimun 
+        # add a shaded region between minimun
         # and maximum curve of interactions
         # -----------------------------------------------------------
-        geom_ribbon(aes(x = x, ymin = 0, ymax = ydiff), 
-                    fill = fillColor, 
+        geom_ribbon(aes(x = x, ymin = 0, ymax = ydiff),
+                    fill = fillColor,
                     alpha = fillAlpha) +
         geom_line()
       # -----------------------------------------------------------
@@ -548,16 +702,15 @@ sjp.lm.int <- function(fit,
       if (showValueLabels) {
         baseplot <- baseplot +
           geom_text(aes(label = round(ydiff, 1), x = x, y = ydiff),
-                    vjust = 1.5, 
+                    vjust = 1.5,
                     show_guide = FALSE)
       }
     }
     else {
-      baseplot <- ggplot(intdf) + 
-        geom_point(aes(x = x, y = y, colour = grp)) +
+      baseplot <- ggplot(intdf) +
         # add a shaded region between minimun and maximum curve of interactions
-        geom_ribbon(aes(x = x, ymin = ymin, ymax = ymax), 
-                    fill = fillColor, 
+        geom_ribbon(aes(x = x, ymin = ymin, ymax = ymax),
+                    fill = fillColor,
                     alpha = fillAlpha) +
         geom_line(aes(x = x, y = y, colour = grp))
       # ------------------------------------------------------------
@@ -565,8 +718,9 @@ sjp.lm.int <- function(fit,
       # ------------------------------------------------------------
       if (showValueLabels) {
         baseplot <- baseplot +
-          geom_text(aes(label = round(y, 1), x = x, y = y), 
-                    vjust = 1.5, 
+          geom_point(aes(x = x, y = y, colour = grp)) +
+          geom_text(aes(label = round(y, 1), x = x, y = y),
+                    vjust = 1.5,
                     show_guide = FALSE)
       }
       # ------------------------------------------------------------
@@ -575,29 +729,29 @@ sjp.lm.int <- function(fit,
       # ------------------------------------------------------------
       if (showInterceptLines) {
         baseplot <- baseplot +
-          geom_abline(intercept = b0, 
-                      slope = 0, 
+          geom_abline(intercept = b0,
+                      slope = 0,
                       colour = interceptLineColor) +
-          geom_abline(intercept = est_b, 
-                      slope = 0, 
+          geom_abline(intercept = est_b,
+                      slope = 0,
                       colour = estLineColor)
         if (showInterceptLabels) {
           baseplot <- baseplot +
-            annotate("text", 
-                     label = annoLabels[1], 
-                     x = -Inf, 
-                     hjust = -0.05, 
-                     vjust = -0.5, 
-                     colour = lineLabelColor, 
-                     size = lineLabelSize, 
+            annotate("text",
+                     label = annoLabels[1],
+                     x = -Inf,
+                     hjust = -0.05,
+                     vjust = -0.5,
+                     colour = lineLabelColor,
+                     size = lineLabelSize,
                      y = b0) +
-            annotate("text", 
-                     label = annoLabels[2], 
-                     x = -Inf, 
-                     hjust = -0.05, 
-                     vjust = -0.5, 
-                     colour = lineLabelColor, 
-                     size = lineLabelSize, 
+            annotate("text",
+                     label = annoLabels[2],
+                     x = -Inf,
+                     hjust = -0.05,
+                     vjust = -0.5,
+                     colour = lineLabelColor,
+                     size = lineLabelSize,
                      y = est_b)
         }
       }
@@ -605,7 +759,7 @@ sjp.lm.int <- function(fit,
     # ------------------------------------------------------------------------------------
     # build plot object with theme and labels
     # ------------------------------------------------------------------------------------
-    baseplot <- baseplot + 
+    baseplot <- baseplot +
       # set plot and axis titles
       labs(title = labtitle, x = labx, y = laby) +
       # set axis scale breaks
@@ -642,7 +796,7 @@ sjp.lm.int <- function(fit,
   # -------------------------------------
   # return results
   # -------------------------------------
-  invisible (structure(class = "sjplmint",
+  invisible (structure(class = "sjpint",
                        list(plot.list = plotlist,
                             df.list = dflist)))
-}
\ No newline at end of file
+}
